import numpy as np
import matplotlib.pyplot as plt
from scipy.integrate import ode

plt.rcParams['font.size'] = 16
#--- system parameters ---
m = 1
k = 4
a = 1
b = .02
R = .3
A = 2
# --- integration parameters ---
tEnd = 100
dt = .01
time = []
v = []
v0 = [20, 5]
# --- ode model
def oscModel( t, v):
    vin = np.tanh( A*R*v[0] )
    dvdt = np.dot( np.array([[-R/a/m-b/m, -1/a/m],[k/a,0]]),v )+ vin/R/a
    return( dvdt )

# --- define ode problem
r = ode(oscModel).set_integrator('zvode',method = 'bdf')
r.set_initial_value(v0,0)

while r.successful() and r.t<tEnd:
    r.integrate(r.t+dt)
    time.append(r.t)
    v.append(r.y)
v = np.array(v)
plt.figure()
# plt.plot(time,v[:,1])
plt.plot(time,R*v[:,0])
plt.xlabel('Time $t$ [sec]')
plt.grid(True)
plt.ylabel('Output voltage $v_{out}(t)$ [V]')
plt.show()