from pylab import *
from enthought.mayavi import mlab

n  = 1                                  # current mode
N1 = 20                              # Number of elements in the r-direction
N2 = 20                              # Number of elements in the theta-direction
N  = N1*N2		    # Total number of elements - compare to 1D (radial only model) !
r_a= 200e-6		    # Radius [m]
h = 1e-6		    # Height [m]
nu = 0.3	                 # Poisson ratio
Y = 150e9		    # Young's modulus [N/m**2]
rho = 2330		    # Mass density [kg/m**3]
D = Y*h**3/12/(1-nu**2)     # Plate modulus

a = zeros((N,N))                # Initialize mass and stiffness matrices
m = zeros((N,N))

dq = 2*pi/N2; dr = r_a/N1  # define the element size
for i in arange(0,N):
     i1 = floor(i*1.0/N1)+.5
     i2 = i % N1 
     ri = r_a*i1/N1 
     qi = 2*pi*i2/N2 +2*pi/3
     m[i,i] = ri*dq*dr*rho*h                   # mass matrix is diagonal as before
     for j in arange(i,N):
          j1 = floor(j*1/N1)+.5
          j2 = j % N1
          rj = r_a*j1/N1
          qj = 2*pi*j2/N2+2*pi/3
          r1 = sqrt(ri**2+rj**2-2*ri*rj*cos(qj-qi))
          rx = r_a**2/ri
          r2 = sqrt(rx**2 + rj**2 -2*rx*rj*cos(qj-qi))
          if i == j:
              a[i,j] = 1/(16*pi*D)*(r_a**2-ri**2)**2/r_a**2
          else:
              a[i,j] = 1/(16*pi*D)*(ri**2*r2**2/r_a**2-r1**2*(1+2*log(ri*r2/r_a/r1)))
              a[j,i] = a[i,j]
          if isnan(a[i,j]):
              print i,j,r1
w,v = eig(dot(a,m))                        # Note that matrix multiplication in Python uses dot() fcn
freq_kHz = 1/sqrt(w)/2/pi/1e3       
# Visualization:                                              
mlab.figure("Modal analysis",(1,1,1),(0,0,0))                 
mlab.clf()                                                    
q,r = meshgrid(linspace(0,2*pi+.001,N2),linspace(0,1,N1))          
uF = v[:,n-1]/max(abs(v[:,n-1]))                              
u = reshape(uF,r.shape)                                       
mlab.mesh(r*cos(q),r*sin(q),real(u),colormap = 'gray')        
fStr = "%2.3f" % freq_kHz[n-1]                                
tit = 'Mode = ' + str(n) + ': f = ' + fStr + ' kHz'           
mlab.title(tit,size =12)                                      
# coeff = (1.015, 2.007, -5)                                  
if n == 1:                                                    
    coeff = 1.0174                                            
elif n == 2:                                                  
    coeff = 2.0074                                            
elif n == 3:                                                  
    coeff = 3.0047                                            
fTheory_kHz = (coeff*pi/r_a)**2 * sqrt(D/rho/h)/2./pi/1.e3    
print "Theoretical frequency [kHz] = " + "%2.3f" % fTheory_kHz