import numpy as np
import matplotlib.pyplot as plt

w = np.linspace(0,1.2,200);
zeta = np.arange(.5,1.3,.2)
plt.figure(figsize = (5,4.5),dpi = 150)
ax = {}
ax['mag'] = plt.axes((.15,.62,.8,.35))
ax['phi'] = plt.axes((.15,.12,.8,.35))
plt.rcParams['font.size'] = 9
plt.rcParams['font.family'] = 'Arial'
plt.rcParams['legend.fontsize']='medium'

lnSt = (':','--','-.','-')
leg = []
d = .25
for i in range(0,len(zeta)):
    leg.append(r'$\zeta$ = '+str(zeta[i]))
i = 0
for zetaC in zeta:
    mag = 1/((1-w**2)**2 + (2*w*zetaC)**2)
    phi = np.arctan2( -2*w*zetaC,1-w**2)*180/np.pi
    plt.axes(ax['mag'])
    plt.plot(w, mag,linestyle = lnSt[i],color = 'k',linewidth = 1)
    plt.hold(True)
    plt.axes(ax['phi'])
    plt.plot(w,phi,linestyle = lnSt[i],color = 'k',linewidth = 1)
    i+=1

ax['mag'].set_yticks((.2,.6,1.,1.4))

plt.ylabel(r'Phase $\angle{H(\omega)}$ [deg]')
plt.xlabel(r'Normalized frequency $\omega/\omega_o$')
#plt.grid(True)
plt.legend( leg, loc = 3)
yl = ax['phi'].get_ylim()
plt.fill((0,.2,.2,0),(yl[0],yl[0],yl[1],yl[1]),color = .7*np.ones(3),alpha = .2)
ax['phi'].set_yticks((0,-30,-60,-90,-120))
plt.text(ax['phi'].get_xlim()[1]-np.diff(plt.xlim())/20,yl[1]-np.diff(yl)/20,'(b)  ',
         horizontalalignment = 'right',
         verticalalignment = 'top')
plt.axes(ax['mag'])
plt.ylabel('Amplitude $|H(\omega)|/\omega_o^2$')
#plt.grid(True)
plt.axes(ax['mag'])
yl = ax['mag'].get_ylim()
plt.fill((0,.2,.2,0),(yl[0],yl[0],yl[1],yl[1]),color = .7*np.ones(3),alpha = .2)
plt.text(ax['mag'].get_xlim()[1]-np.diff(plt.xlim())/20,yl[1]-np.diff(yl)/20,'(a)  ',
         horizontalalignment = 'right',
         verticalalignment = 'top')
plt.text(.1,yl[0]+np.diff(yl)/10,'Operating\nfrequency\nrange',
         horizontalalignment = 'center')         
plt.show()
plt.savefig('Fig7p14.png')
plt.savefig('Fig7p14.eps')