# -*- coding: utf-8 -*-
"""
Created on Wed Dec 21 04:28:44 2011

@author: NGN
"""

import sympy
import numpy as np
import matplotlib.pyplot as plt

# Symbolic part
x,i,N,Rc,d,A,uo = sympy.symbols('x,io,N,Rc,d,A,uo',real = True)

L = N**2/(Rc+(d-x)/(uo*A))   # inductance
f = i**2*L.diff(x)/2         # force of electric origin

print '\n\n\nForce of electric origin\n\nfe = ',f
# Numerical values: 
Lb = 1e-3          # beam length, m
w = 100e-6         # beam width, m
h = 2e-6           # beam thickness, m 
dn = 20e-6         # nominal electrode gap, m (numerical value)
lCore = 2e-3       # length of core, m
Acore = 1e-8       # area, m**2
ur = 2000          # relative mu
uon = 4*np.pi*1e-7 # permeability of air
Nn = 8             # number of turns (numerical value)
Ysi = 1.68e11       # Ysi, Pa

Rcore = lCore/(ur*uon*Acore)

fn= f.subs([(Rc,Rcore),(A,Acore),(uo,uon),(d,dn),(N,Nn)])
felast = Ysi*h**3*w*x/(4*(Lb-w/2)**3)

io = np.linspace(0,13e-3,40)
xo = np.zeros(len(io))              # pre-allocate the array for xo
for k in range(len(io)):
    fres = fn.subs(i,io[k])-felast  # force resultant -> zero
    zers = sympy.solve(fres,x)      # find zeros of the 3rd-order poly
    xo[k] = min(zers)               # there are three solutions
#    print zers
# plot the results:
plt.rcParams['font.size'] = 18
plt.figure()    


ind, = np.nonzero(xo<=20e-6)
plt.plot(io[ind]*1e3,(dn-xo[ind])*1e6,linewidth = 2, color = 'k')
plt.plot(io[ind[-1]]*1e3,(dn-xo[ind[-1]])*1e6,marker = 'o',color = 'k',
         markerfacecolor = 'k')
plt.text(io[ind[-1]]*1e3,(dn-xo[ind[-1]])*1e6,
         (r'$i_o$ = %.1f mA ')%(io[ind[-1]]*1e3),
         horizontalalignment = 'right')      
plt.xlabel('Current $i_o$ [mA]')
plt.ylabel('Gap spacing $d-x_o$ [$\mu$m]')
plt.title((r'$Y_{Si}$ = %d GPa')%(Ysi*1e-9))
plt.grid(True)
plt.show()
    
